package com.xinelu.manage.mapper.hospitaldepartmentinfo;

import com.xinelu.manage.domain.hospitaldepartmentinfo.HospitalDepartmentInfo;
import java.util.List;
import org.apache.ibatis.annotations.Param;

/**
 * 科室信息管理Mapper接口
 *
 * @author zh
 * @date 2023-02-13
 */
public interface HospitalDepartmentInfoMapper {
    /**
     * 查询科室信息管理
     *
     * @param id 科室信息管理主键
     * @return 科室信息管理
     */
    HospitalDepartmentInfo selectHospitalDepartmentInfoById(Long id);

    /**
     * 查询科室信息管理列表
     *
     * @param hospitalDepartmentInfo 科室信息管理
     * @return 科室信息管理集合
     */
    List<HospitalDepartmentInfo> selectHospitalDepartmentInfoList(HospitalDepartmentInfo hospitalDepartmentInfo);

    /**
     * 新增科室信息管理
     *
     * @param hospitalDepartmentInfo 科室信息管理
     * @return 结果
     */
    int insertHospitalDepartmentInfo(HospitalDepartmentInfo hospitalDepartmentInfo);

    /**
     * 修改科室信息管理
     *
     * @param hospitalDepartmentInfo 科室信息管理
     * @return 结果
     */
    int updateHospitalDepartmentInfo(HospitalDepartmentInfo hospitalDepartmentInfo);

    /**
     * 删除科室信息管理
     *
     * @param id 科室信息管理主键
     * @return 结果
     */
    int deleteHospitalDepartmentInfoById(Long id);

    /**
     * 批量删除科室信息管理
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteHospitalDepartmentInfoByIds(Long[] ids);

    /**
     * 批量新增科室信息管理
     *
     * @param hospitalDepartmentInfoList 科室信息管理
     * @return 结果
     */
    int insertHospitalDepartmentList(List<HospitalDepartmentInfo> hospitalDepartmentInfoList);

    /**
     * 根据医院id及科室名称查询同科室名称数量
     *
     * @param hospitalId     医院id
     * @param departmentName 科室名称
     * @return 数量
     */
    int selectHospitalDepartmentCount(@Param("hospitalId") Long hospitalId, @Param("departmentName") String departmentName);

    /**
     * 查询当前医院下的所有科室信息
     *
     * @param hospitalIdList 医院id集合
     * @return 科学信息
     */
    List<HospitalDepartmentInfo> getDepartmentInfoList(@Param("hospitalIdList") List<Long> hospitalIdList);
}
